#include <stdio.h>
#include <string.h>

const long MAX_TURNS_COUNT = 51; //51
const long MAX_SQUARES_COUNT = 10; //10
const long MAX_MONSTERS_HP = 100; //100
const long MAX_MOVES_VARIANTS_COUNT = 12; //12

typedef unsigned char u8;

template<class Type>Type Min(const Type &a, const Type &b){return a < b ? a : b;}
template<class Type>Type Max(const Type &a, const Type &b){return a > b ? a : b;}

struct tMonsters
{
	static long speed;
	static long monsterHP;
	long iSquare;
	long HP;
	long cMonsters(void)const
	{
		return (HP + monsterHP - 1) / monsterHP;
	}
};

long tMonsters::speed = 0;
long tMonsters::monsterHP = 0;

struct tHero
{
	static long maxHP;
	static long healPower;
	static long lightingPower[MAX_SQUARES_COUNT];
	long HP;
};

long tHero::maxHP = 0;
long tHero::healPower = 0;
long tHero::lightingPower[MAX_SQUARES_COUNT] = {0};

struct tField
{
	static long cSquares;
	tHero hero;
	tMonsters monsters;
};

long tField::cSquares = 0;

class MoveVariant
{
protected:
	void MonstersMove(tMonsters *monsters)const
	{
		monsters->iSquare = Max(0L, monsters->iSquare - tMonsters::speed);
	}

	void MonstersStrike(tField *field)const
	{
		if(!field->monsters.iSquare)
			field->hero.HP =
				Max(0L, field->hero.HP - field->monsters.cMonsters());
	}
public:
	virtual ~MoveVariant(){}
	virtual void MakeMove(const tField &oldField, tField *newField)const = 0;
	virtual void WriteMove(void)const = 0;
};

class MoveHeal : public MoveVariant
{
public:
	virtual void MakeMove(const tField& oldField, tField *newField)const
	{
		*newField = oldField;
		newField->hero.HP =
			Min(newField->hero.HP + tHero::healPower, tHero::maxHP);
		MonstersMove(&newField->monsters);
		MonstersStrike(newField);
	}

	virtual void WriteMove(void)const
	{
		puts("H");
	}

	virtual ~MoveHeal(){}
};

class MoveLighting : public MoveVariant
{
public:
	virtual void MakeMove(const tField &oldField, tField *newField)const
	{
		*newField = oldField;
		newField->monsters.HP =
			Max
			(
				0L,
				newField->monsters.HP -
					tHero::lightingPower[newField->monsters.iSquare]
			);
		MonstersMove(&newField->monsters);
		MonstersStrike(newField);
	}

	virtual void WriteMove(void)const
	{
		puts("L");
	}

	virtual ~MoveLighting(){}
};

class MoveTeleport : public MoveVariant
{
	u8 iSquare;
public :
	MoveTeleport(u8 initiSquare) : iSquare(initiSquare) {}

	virtual void MakeMove(const tField &oldField, tField *newField)const
	{
		*newField = oldField;
		newField->monsters.iSquare = iSquare;
		MonstersMove(&newField->monsters);
		MonstersStrike(newField);
	}

	virtual void WriteMove(void)const
	{
		printf("T %ld\n", long(iSquare + 1));
	}

	virtual ~MoveTeleport(){}
};

int main(void)
{
	static u8 maxHeroHP[MAX_TURNS_COUNT][MAX_SQUARES_COUNT][MAX_MONSTERS_HP + 1];
	u8 (*prevTurnSquare)[MAX_SQUARES_COUNT][MAX_MONSTERS_HP + 1];
	u8 (*prevTurnMonstersHP)[MAX_SQUARES_COUNT][MAX_MONSTERS_HP + 1];
	u8 (*prevTurnMove)[MAX_SQUARES_COUNT][MAX_MONSTERS_HP + 1];

	prevTurnSquare = new u8[MAX_TURNS_COUNT][MAX_SQUARES_COUNT][MAX_MONSTERS_HP + 1];
	prevTurnMonstersHP = new u8[MAX_TURNS_COUNT][MAX_SQUARES_COUNT][MAX_MONSTERS_HP + 1];
	prevTurnMove = new u8[MAX_TURNS_COUNT][MAX_SQUARES_COUNT][MAX_MONSTERS_HP + 1];

	if(!prevTurnSquare || !prevTurnMonstersHP || !prevTurnMove)
		fputs("Not enough memory", stderr);

	freopen("heroes.in", "r", stdin);
	freopen("heroes.out", "w", stdout);

	memset(maxHeroHP, 0, sizeof(maxHeroHP));

	long heroMP, cMonsters;
	scanf("%ld %ld %ld %ld %ld %ld %ld",
		&tField::cSquares, &tHero::maxHP, &heroMP, &tMonsters::monsterHP,
		&cMonsters, &tMonsters::speed,
		&tHero::healPower);
	long iSquare;
	for(iSquare = 0; iSquare < tField::cSquares; ++iSquare)
		scanf("%ld", &tHero::lightingPower[iSquare]);

	long maxMonstersHP = tMonsters::monsterHP * cMonsters;
	maxHeroHP[0][tField::cSquares - 1][maxMonstersHP] = tHero::maxHP;

	MoveVariant *moves[MAX_MOVES_VARIANTS_COUNT];
	long cMovesVariants = 0;
	moves[cMovesVariants++] = new MoveHeal();
	moves[cMovesVariants++] = new MoveLighting();
	long iTeleportSquare;
	for(iTeleportSquare = 0; iTeleportSquare < tField::cSquares; ++iTeleportSquare)
		moves[cMovesVariants++] = new MoveTeleport(iTeleportSquare);

	long iTurn, monstersHP, iMove;
	tField oldField, newField;
	for(iTurn = 0; iTurn < heroMP; ++iTurn)
	{
		for(iSquare = 0; iSquare < tField::cSquares; ++iSquare)
			for(monstersHP = 0; monstersHP <= maxMonstersHP; ++monstersHP)
				if(maxHeroHP[iTurn][iSquare][monstersHP])
				{
					oldField.hero.HP = maxHeroHP[iTurn][iSquare][monstersHP];
					oldField.monsters.HP = monstersHP;
					oldField.monsters.iSquare = iSquare;
					for(iMove = 0; iMove < cMovesVariants; ++iMove)
					{
						moves[iMove]->MakeMove(oldField, &newField);
						if
						(
							maxHeroHP[iTurn + 1][newField.monsters.iSquare][newField.monsters.HP]
								< newField.hero.HP
						)
						{
							maxHeroHP[iTurn + 1][newField.monsters.iSquare][newField.monsters.HP]
								= newField.hero.HP;
							prevTurnSquare[iTurn + 1][newField.monsters.iSquare][newField.monsters.HP]
								= oldField.monsters.iSquare;
							prevTurnMonstersHP[iTurn + 1][newField.monsters.iSquare][newField.monsters.HP]
								= oldField.monsters.HP;
							prevTurnMove[iTurn + 1][newField.monsters.iSquare][newField.monsters.HP]
								= iMove;

						}
						if(!newField.monsters.HP)goto GameOver;
					}
				}
	}

	for(iSquare = 0; iSquare < tField::cSquares; ++iSquare)
		if(maxHeroHP[heroMP][iSquare][0])break;

GameOver:

	if(iTurn != heroMP)
	{
		iSquare = newField.monsters.iSquare;
		++iTurn;
	}

	static long movesStack[MAX_TURNS_COUNT], stackTop = 0;

	if(iSquare == tField::cSquares)puts("DEFEATED");
	else
	{
		puts("VICTORIOUS");
		monstersHP = 0;
		for(iTurn; iTurn > 0; --iTurn)
		{
			static long prevSquare, prevMonstersHP;
			prevSquare = prevTurnSquare[iTurn][iSquare][monstersHP];
			prevMonstersHP = prevTurnMonstersHP[iTurn][iSquare][monstersHP];
			movesStack[stackTop++] = prevTurnMove[iTurn][iSquare][monstersHP];
			iSquare = prevSquare;
			monstersHP = prevMonstersHP;
		}

		for(;stackTop;--stackTop)
			moves[movesStack[stackTop - 1]]->WriteMove();
	}

	for(;cMovesVariants;--cMovesVariants)delete moves[cMovesVariants - 1];

	delete[] prevTurnSquare;
	delete[] prevTurnMonstersHP;
	delete[] prevTurnMove;

	fclose(stdout);
	fclose(stdin);

	return 0;
}